@@ -7,7 +7,7 @@ require UR;
 use Scalar::Util qw(blessed);
 
 our @ISA = ('UR::ModuleBase');
-our $VERSION = '0.01';
+our $VERSION = $UR::VERSION;;
 
 sub class { ref($_[0]) || $_[0] }
 
@@ -34,7 +34,7 @@ sub __display_name__ {
     my $self = shift;
     my $context = shift;
     
-    my $name = $_[0]->id;
+    my $name = $self->id;
     $name =~ s/\t/ /g;
     return $name;
 
@@ -141,12 +141,17 @@ sub DESTROY {
             return;
         }
         else {
+            if ($ENV{'UR_DEBUG_OBJECT_RELEASE'}) {
+                print STDERR "MEM DESTROY object $obj class ",$obj->class," id ",$obj->id,"\n";
+            }
             $obj->unload();
-            #print "TOSSING $obj.  Found $obj .\n";
             return $obj->SUPER::DESTROY();
         }
     }
     else {
+        if ($ENV{'UR_DEBUG_OBJECT_RELEASE'}) {
+            print STDERR "MEM DESTROY object $obj class ",$obj->class," id ",$obj->id,"\n";
+        }
         $obj->SUPER::DESTROY();
     }
 };
@@ -310,7 +315,7 @@ sub create {
         # This has to occur for all subclasses which represent table rows.
         
         my @id_property_names = $co->id_property_names;
-        my @values = $co->class_name->decomposed_id( $id );
+        my @values = $co->resolve_ordered_values_from_composite_id( $id );
         $#values = $#id_property_names;
         push @extra, map { $_ => shift(@values) } @id_property_names;
         
@@ -568,6 +573,9 @@ sub delete_object {
     # Turn our $self reference into a UR::DeletedRef.
     # Further attempts to use it will result in readable errors.
     # The object can be resurrected.
+    if ($ENV{'UR_DEBUG_OBJECT_RELEASE'}) {
+        print STDERR  "MEM DELETE object $self class ",$self->class," id ",$self->id,"\n";
+    }
     UR::DeletedRef->bury($self);
 
     return $self;
